#!/bin/sh

if [ -z "$1" ] || ! [ -d "bin-$1" ] ; then
	echo "Usage: $0 DIETARCH" >&2
	exit 1
fi
DIET="bin-$1/diet"

TESTS="
test/select.c
debian/unittests/tc523086.c
debian/unittests/t-ascii1.c
debian/unittests/signal.c
debian/unittests/gettimeofday.c
"

# Figure out longest len so we can pretty-print the test results.
LONGEST_LEN=0
for i in $TESTS; do
  if [ ${#i} -gt $LONGEST_LEN ] ; then
    LONGEST_LEN=${#i}
  fi
done

HAD_ERROR=0

echo "Running dietlibc unittests:"
for testname in $TESTS ; do
	printf "  %-*s: build: " $LONGEST_LEN $testname
	$DIET -v -Os gcc -nostdinc -static -o debian/unittests/ttt $testname >debian/unittests/gcc.out 2>&1
	RC=$?
	if [ $RC -ne 0 ] ; then
		printf "ERROR\n"
		echo
		echo "BUILD ERROR for $testname (rc = $RC), gcc output is:"
		echo "------------------------------------------------------------"
		cat debian/unittests/gcc.out
		echo "------------------------------------------------------------"
		echo
		rm -f debian/unittests/gcc.out debian/unittests/ttt
		HAD_ERROR=1
		continue
	fi
	printf "OK    run: "
	rm -f debian/unittests/gcc.out
	debian/unittests/ttt >debian/unittests/run.out 2>&1
	RC=$?
	if [ $RC -ne 0 ] ; then
		printf "ERROR\n"
		echo
		echo "RUN ERROR for $testname (rc = $RC), test output is:"
		echo "------------------------------------------------------------"
		cat debian/unittests/run.out
		echo "------------------------------------------------------------"
		echo
		rm -f debian/unittests/run.out debian/unittests/ttt
		HAD_ERROR=1
		continue
	fi
	rm -f debian/unittests/run.out debian/unittests/ttt
	printf "OK\n"
done

exit $HAD_ERROR
